from .notelate import Notelate
import requests
import os
import sys
import glob
import shutil
import warnings
warnings.simplefilter("ignore")


# templates in this list is installed by default
template_list = [
    'basic',
    'dark'
]


def main():
    nl = Notelate(template_list)
    if len(sys.argv) == 1:
        templat_name = 'basic'
        nl.copy_template(templat_name)
        return True

    if sys.argv[1] == 'list':
        print('printing template list in local')
        nl.print_list(local=False)
    elif sys.argv[1] == 'local':
        print('printing template list in local')
        nl.print_list(local=True)
    elif sys.argv[1] == 'add':
        nl.add_template_path(sys.argv[2])
    else:
        templat_name = sys.argv[1]
        nl.copy_template(templat_name)


if __name__ == '__main__':
    main()



import requests
import os
import sys
import glob
import shutil
import urllib
import numpy as np
import warnings
warnings.simplefilter("ignore")

path_list = os.path.dirname(os.path.abspath(
    __file__)) + '/temp_paths.npy'


class Notelate:
    def __init__(self, template_list):
        if os._exists(path_list):
            self.template_path_list = np.load(path_list)
        else:
            path = os.path.dirname(os.path.abspath(
                __file__)).replace('\\scripts', '')
            self.template_path_list = np.array([path + '\\templates\\'])
            np.save(path_list, self.template_path_list)
        print('template folder is {}'.format(self.template_path_list))

        self.template_list = template_list
        self.init_template()

    def init_template(self):
        for t in self.template_list:
            if self.check_local(t):
                pass
            else:
                self.fetch_template(t)

    def fetch_template(self, template_name):
        base_url = 'https://raw.githubusercontent.com/punisuke/notelate/master/notelate/templates/'
        try:
            url = f'{base_url}{template_name}.ipynb'
            filename = f'{self.template_path_list[0]}{template_name}.ipynb'
            urllib.request.urlretrieve(url, filename)
        except Exception as e:
            print(e)
            print(f'error in downloading template {template_name}')

    def print_list(self, local=True):
        temp_list = []
        if local:
            for tp in self.template_path_list:
                temp_list += glob.glob(tp+'*.ipynb')
        else:
            for tp in self.template_path_list:
                temp_list += glob.glob(tp+'*.ipynb')

        for t in temp_list:
            print(t.split('\\')[-1].replace('.ipynb', ''))

    def check_local(self, template_name):
        for tp in self.template_path_list:
            if os.path.exists(tp + '{}.ipynb'.format(template_name)):
                return tp
        return False

    def add_template_path(self, path):
        self.template_path_list = np.append(self.template_path_list, path)
        np.save(path_list, self.template_path_list)
        print('template folder is {}'.format(self.template_path_list))

    def copy_template(self, template_name):
        e = self.check_local(template_name)
        if e:
            template_name += '.ipynb'
            old_path = e + template_name
            new_path = os.getcwd() + '/' + template_name
            shutil.copyfile(old_path, new_path)
            print('"{}" is generated'.format(template_name))
        else:
            print('"{}" does not exist'.format(template_name))


if __name__ == '__main__':
    nl = Notelate(['basic'])
    nl.init_template()



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import absolute_import
from __future__ import unicode_literals
import os

from setuptools import setup, find_packages

try:
    with open('README.md') as f:
        readme = f.read()
except IOError:
    readme = ''


def _requires_from_file(filename):
    return open(filename).read().splitlines()


# version
here = os.path.dirname(os.path.abspath(__file__))
version = next((line.split('=')[1].strip().replace("'", '')
                for line in open(os.path.join(here,
                                              'notelate',
                                              '__init__.py'))
                if line.startswith('__version__ = ')),
               '0.0.5')

if __name__ == '__main__':
    setup(
        name="notelate",
        version=version,
        url='https://github.com/punisuke/notelate',
        author='punisuke',
        author_email='punisuke-@outlook.jp',
        maintainer='punisuke',
        maintainer_email='punisuke-@outlook.jp',
        description='generate jupyter notebook/lab template via command line',
        long_description=readme,
        long_description_content_type="text/markdown",
        packages=find_packages(),
        install_requires=_requires_from_file('requirements.txt'),
        license="MIT",
        classifiers=[
            'Programming Language :: Python :: 2',
                'Programming Language :: Python :: 2.7',
                'Programming Language :: Python :: 3',
                'Programming Language :: Python :: 3.3',
                'Programming Language :: Python :: 3.4',
                'License :: OSI Approved :: MIT License',
        ],
        entry_points="""
            # -*- Entry points: -*-
            [console_scripts]
            notelate = notelate.scripts.app:main
            """,
    )
